using System.Collections.Generic;
using UnityEngine;

// This is an example script demonstrating how to register JSONStorableStrings with the UIAssist plugin to receive
// updates whenever the UIAssist Gaze Targets change. There are four standard UIAssist gaze target types support - the last gazed at Atom,
// Person, Female and Male.
// A callback method can optionally be assigned to each JSONStorableString which will be activated when the registered gaze target
// changes.
// Communication with UIAssist follows a pattern outlined by AcidBubbles - https://github.com/vam-community/vam-plugins-interop-specs

public class UIAGazeTargetReceiver : MVRScript
{
    private JSONStorableString _uiaLastGazedAtAtomJSON;
    private JSONStorableString _uiaLastGazedAtFemaleJSON;
    private JSONStorableString _uiaLastGazedAtMaleJSON;
    private JSONStorableString _uiaLastGazedAtPersonJSON;

    const string pluginName = "UIAGazeTargetReceiver";
    const string pluginAuthor = "JayJayWon";
    const string pluginVersion = "v1.0";

    public override void Init()
    {
        // Create a JSONStorableString for each Gaze Target type required. paramName for the JSONStorableString can be any unique value.
        _uiaLastGazedAtAtomJSON = new JSONStorableString("uiaLastGazedAtAtom","");
        _uiaLastGazedAtPersonJSON = new JSONStorableString("uiaLastGazedAtPerson", "");
        _uiaLastGazedAtFemaleJSON = new JSONStorableString("uiaLastGazedAtFemale", "");
        _uiaLastGazedAtMaleJSON = new JSONStorableString("uiaLastGazedAtMale", "");
        

        // Registering the strings makes them accessible via VAM triggers
        // Can be removed if not requred
        RegisterString(_uiaLastGazedAtAtomJSON);
        RegisterString(_uiaLastGazedAtFemaleJSON);
        RegisterString(_uiaLastGazedAtMaleJSON);
        RegisterString(_uiaLastGazedAtPersonJSON);

        // Text fields to display the Target Atom values on this plugins UI
        // Can be removed if not requred
        UIDynamicTextField textfield1 = CreateTextField(_uiaLastGazedAtAtomJSON);
        textfield1.height = 10;
        UIDynamicTextField textfield2 = CreateTextField(_uiaLastGazedAtPersonJSON);
        textfield2.height = 10;
        UIDynamicTextField textfield3 = CreateTextField(_uiaLastGazedAtFemaleJSON);
        textfield3.height = 10;
        UIDynamicTextField textfield4 = CreateTextField(_uiaLastGazedAtMaleJSON);
        textfield4.height = 10;
        
        // Help text
        // Can be removed if not requred
        JSONStorableString helpText = new JSONStorableString("helpText", "This plugin demonstrates how other plugins can register with the UIAssist plugin to access the atom names of the last gazed at Atom, Person, Female and Male. Each of the text boxes on the left is dynamically updated with these values.\nThe top text box contains the last Gazed at Atom.\nThe second text box contains the last gazed at Person.\nThe third text box contains the last gazed at Female.\nThe final text box contains the last gazed at Male.");
        UIDynamicTextField helpTextField = CreateTextField(helpText,true);
        helpTextField.height = 500;

        // Registers this plugin with other plugins using interop spec
        SuperController.singleton.BroadcastMessage("OnActionsProviderAvailable", this, SendMessageOptions.DontRequireReceiver);

        JSONStorableString pluginVersionJSON = new JSONStorableString("PluginVersion", "");
        UIDynamicTextField dtext = CreateTextField(pluginVersionJSON, false);
        pluginVersionJSON.val = pluginName + " " + pluginVersion + "\nby " + pluginAuthor;
        dtext.height = 1;
    }

    public void OnDestroy()
    {
        // Unregisters this plugin with other plugins using interop spec
        SuperController.singleton.BroadcastMessage("OnActionsProviderDestroyed", this, SendMessageOptions.DontRequireReceiver);
    }


    // This method will be called by the UIAssist plugin when available. Add all required gaze targets to the supplied gazeTargets dictionary.
    public void OnGazeTargetsListRequested(Dictionary<string, object> gazeTargets)
    {
        //Add a dictionary entry for each of the JSONStrings that require updating. The Dictionary Key determines which gaze target (Atom, Person, Male or Female) will be registered
        gazeTargets.Add("UIALastGazedAtAtom", _uiaLastGazedAtAtomJSON);
        gazeTargets.Add("UIALastGazedAtFemale", _uiaLastGazedAtFemaleJSON);
        gazeTargets.Add("UIALastGazedAtMale", _uiaLastGazedAtMaleJSON);
        gazeTargets.Add("UIALastGazedAtPerson", _uiaLastGazedAtPersonJSON);
    }
}
